==> xoonips-3.41.tar.gz: xoonips-3.41/itemtypes/xnpbinder/language/ja_utf8/modinfo.php <==
<?php
// $Revision: 1.1.2.2 $
// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //
define("_MI_XNPBINDER_NAME","XooNIps Binder Item Type Module");
define("_MI_XNPBINDER_DESC","XooNIps Binder Item Type Module");
define( "_MI_XNPBINDER_CONTENT_EMPTY_NOTIFY", "空のバインダーを通知" );
define( "_MI_XNPBINDER_CONTENT_EMPTY_NOTIFYCAP", "公開バインダーが空になった場合に通知する" );
define( "_MI_XNPBINDER_CONTENT_EMPTY_NOTIFYDSC", "公開バインダーに登録されたアイテムが0個になった場合に通知を受け取る．" );
define( "_MI_XNPBINDER_CONTENT_EMPTY_NOTIFYSBJ", "公開バインダーが空になりました" );
?>

==> xoonips-3.50.tar.gz: xoonips-3.50/itemtypes/xnpbinder/language/ja_utf8/modinfo.php <==
<?php

// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //
define('_MI_XNPBINDER_NAME', 'XooNIps Binder Item Type Module');
define('_MI_XNPBINDER_DESC', 'XooNIps Binder Item Type Module');
define('_MI_XNPBINDER_CONTENT_EMPTY_NOTIFY', '空のバインダーを通知');
define('_MI_XNPBINDER_CONTENT_EMPTY_NOTIFYCAP', '公開バインダーが空になった場合に通知する');
define('_MI_XNPBINDER_CONTENT_EMPTY_NOTIFYDSC', '公開バインダーに登録されたアイテムが0個になった場合に通知を受け取る．');
define('_MI_XNPBINDER_CONTENT_EMPTY_NOTIFYSBJ', '公開バインダーが空になりました');
